import gradio as gr
from transformers import pipeline
from gradio.themes.utils import sizes


theme = gr.themes.Default(radius_size=sizes.radius_none).set(
    block_label_text_color = '#4D63FF',
    block_title_text_color = '#4D63FF',
    button_primary_text_color = '#4D63FF',
    button_primary_background_fill='#FFFFFF',
    button_primary_border_color='#4D63FF',
    button_primary_background_fill_hover='#EDEFFF',
)


translator = pipeline("translation_en_to_hi", model="Helsinki-NLP/opus-mt-en-hi")

def translate(input_text):
    output_text = translator(input_text, max_length=1000)[0]['translation_text']

    return output_text

with gr.Blocks(theme=theme, css="footer {visibility: hidden}") as demo:
    gr.Markdown("""
    <div align='center' ><font size='60'>英语到印地语的翻译</font></div>
    """)
    with gr.Row():
        with gr.Column():
            box1 = gr.Textbox(label="英语")
            with gr.Row():
                button = gr.Button("提交", variant="primary")
                clear = gr.Button("清除", variant="primary")
        box2 = gr.Textbox(label="印地语")

    button.click(fn=translate, inputs=box1, outputs=box2)
    clear.click(lambda x: gr.update(value=''), [], [box1])
    examples = gr.Examples(examples=[['I am happy!'], ['I like you!']],  inputs=[box1], label="例子")


if __name__ == "__main__":
    demo.queue(concurrency_count=3)
    demo.launch(server_name = "0.0.0.0")


